/**
	$Id: OnSaveAction.java 5490 2010-11-15 12:53:05Z nicklas $

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions.edit;

import net.sf.basedb.util.extensions.Action;

/**
	Action that is called when an item is saved in gui. Actions are called after
	all regular properties have been updated. It is recommended that implemting
	classes extend the {@link AbstractOnSaveAction} class since we may add more 
	callback methods to this interface in the future.
	<p>
	
	The {@link #onSave()} method is called first and then either {@link 
	#onCommit()} or {@link #onRollback(Exception)}. Note that <code>onRollback</code>
	is called for all exceptions, even if they happen before the <code>onSave</code>
	method has been called.

	@author Nicklas
	@since 2.17
	@base.modified $Date: 2010-11-15 13:53:05 +0100 (Mon, 15 Nov 2010) $
*/
public interface OnSaveAction
	extends Action
{
	
	/**
		This event is fired first to let the action do something with
		the current item. Implementors may throw an exception from this
		method to indicate that something went wrong. If so, any
		remaining extensions will be unprocessed and the {@link #onRollback(Exception)}
		is called.
	*/
	public void onSave();
	
	/**
		This event is fired after a successful commit. Implementors
		should not throw any exceptions from this method since it
		may confuse users to see error messages and may cause other
		extensions to not be called.
	*/
	public void onCommit();
	
	/**
		This event is fired after an error that caused the save action
		to rollback. Implementors should not throw any exceptions from 
		this method since it may hide original exception and may cause
		other extensions to not be called.
		@param ex The exception that caused the transaction to rollback
	*/
	public void onRollback(Exception ex);
	
}
