package net.sf.basedb.clients.web.extensions.list;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import net.sf.basedb.core.Annotatable;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.StringUtil;
import net.sf.basedb.util.formatter.Formatter;
import net.sf.basedb.util.listable.SourceItemTransformer;

/**
	Related item column that get values from an extension.

	@author nicklas
	@since 3.19.4
*/
public class RelatedItemExtensionColumn 
	extends RelatedItemColumn
{

	/**
		The named subcontext to use when using the extensions.
	*/
	public static final String SUBCONTEXT = "RelatedItemColumns";

	private final ListColumnAction<Annotatable, ?> action;
	
	@SuppressWarnings({ "unchecked", "rawtypes" })
	RelatedItemExtensionColumn(DbControl dc, int index, Specification spec, RelatedItemHelper helper, ListColumnAction<Annotatable, ?> action)
	{
		super(dc, index, spec, helper);
		this.action = action;
		
		setValueType(action.getValueType());
		setProperty(action.getProperty());
		setFilterable(action.isFilterable());
		if (action.isFilterable())
		{
			setFilterProperty("/"+spec.directionRaw+"/"+spec.targetType.name()+"/"+spec.subtype+"/"+StringUtil.coalesce(action.getFilterProperty(), action.getProperty()));
		}
		setExportable(action.isExportable());
		if (action.isExportable())
		{
			setExportFormatter(action.getExportFormatter());
			setExportProperty(action.getExportProperty());
		}
		if (!isLazy()) setFormatter((Formatter)action.getCollectionFormatter());
		
		setCellClass(action.getCellClass());
		setCellStyle(action.getCellStyle());
		setDisableOverflowCheck(action.getDisableOverflowCheck());
		setEnumeration(action.getEnumeration());
		setTitle(spec.generateTitle(action.getTitle()));
		setSubtitle(action.getSubtitle());
		setTooltip(spec.generateTooltip(StringUtil.coalesce(action.getTooltip(), action.getTitle())));
	}

	@Override
	public Object getValue(RelatedItemHelper helper, Annotatable item, SourceItemTransformer preTransform) 
	{
		Set<Annotatable> items = getRelatedItems(item, preTransform);
		if (items.size() == 0) return null;

		List<Object> values = new ArrayList<>(items.size());
		for (Annotatable p : items)
		{
			Object v = action.getValue(helper.dc, p);
			if (v != null) values.add(v);
		}
		
		return values.size() == 0 ? null : values;
	}
	
	@Override
	public Object getExportValue(RelatedItemHelper helper, Annotatable item, SourceItemTransformer preTransform) 
	{
		Set<Annotatable> items = getRelatedItems(item, preTransform);
		if (items.size() == 0) return null;

		List<Object> values = new ArrayList<>(items.size());
		for (Annotatable p : items)
		{
			Object v = action.getExportValue(helper.dc, p);
			if (v != null) values.add(v);
		}
		
		return values.size() == 0 ? null : values;
	}

}
