package net.sf.basedb.clients.web.extensions.list;

import net.sf.basedb.core.Annotatable;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemList;
import net.sf.basedb.core.ItemSubtype;
import net.sf.basedb.core.Subtypable;
import net.sf.basedb.util.filter.Filter;

/**
	Filter implementation that accept (annotatable) items of a given subtype.
	It can also accept Item lists with a matching {@link ItemList#getItemSubtype()}
	(or without subtype if the member type matches).

	@author nicklas
	@since 3.16
*/
public class SubtypeFilter 
	implements Filter<Annotatable>
{
	private final Item itemType;
	private final ItemSubtype subtype;
	
	public SubtypeFilter(ItemSubtype subtype) 
	{
		this.subtype = subtype;
		this.itemType = subtype.getMainItemType();
	}
	
	@Override
	public boolean evaluate(Annotatable item) 
	{
		Item thisType = item.getType();
		if (thisType == Item.ITEMLIST)
		{
			ItemList list = (ItemList)item;
			ItemSubtype memberSubtypeType = list.getItemSubtype();
			return (list.getMemberType() == itemType) && (memberSubtypeType == null || subtype.equals(memberSubtypeType));
		}
		else if (thisType != itemType) 
		{
			return false;
		}
		return subtype.equals(((Subtypable)item).getItemSubtype());
	}
}
