/*
	$Id$

	Copyright (C) 2020 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.formatter;

import net.sf.basedb.clients.web.Base;
import net.sf.basedb.clients.web.extensions.fileviewer.FileViewerUtil;
import net.sf.basedb.clients.web.taglib.Page;
import net.sf.basedb.core.File;
import net.sf.basedb.util.formatter.Formatter;

/**
	Formatter implementation that generates a HTML output linking
	a file item. EDIT, VIEW and DOWNLOAD links are created by default.
	
	@author nicklas
	@since 3.17
	@see Base#getLinkedFile(String, File, boolean, boolean, boolean, String)
*/
public class LinkedFileFormatter 
	implements Formatter<File>
{
	
	private final boolean enableEditLink;
	private final boolean enableViewDownload;
	private final FileViewerUtil fileViewer;
	
	public LinkedFileFormatter() 
	{
		this(true, true);
	}

	public LinkedFileFormatter(FileViewerUtil fileViewer) 
	{
		this.fileViewer = fileViewer;
		this.enableEditLink = true;
		this.enableViewDownload = true;
	}
	
	public LinkedFileFormatter(boolean enableEditLink, boolean enableViewDownload)
	{
		this.enableEditLink = enableEditLink;
		this.enableViewDownload = enableViewDownload;
		this.fileViewer = null;
	}

	@Override
	public String format(File file) 
	{
		if (fileViewer != null)
		{
			return Base.getLinkedName(null, file, false, enableEditLink) + " " + fileViewer.renderAsString();
		}
		return Base.getLinkedFile(null, file, false, enableEditLink, enableViewDownload, Page.ROOT());
	}

	@Override
	public File parseString(String value) 
	{
		throw new UnsupportedOperationException("parseString: " + value);
	}

}
