/**
	$Id$

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.migrate;

import java.io.IOException;
import java.io.Writer;
import java.sql.ResultSet;
import java.sql.SQLException;



/**
	Generic writer implementation that writes string values 
	from a result set. An escape map can be given at construction
	time that maps character-values to an escape char[] sequence.
	If no escape sequence is given the original character is written
	as is.  This writer use {@link ResultSet#getString(int)} to read
	data from the result set.
	
	@author Nicklas
	@since 3.1
	@base.modified $Date$
*/
public class TextWriter
	extends AbstractResultWriter
{
	
	private final char[][] ESCAPE;
	
	public TextWriter(ResultSet rs, int index, Writer writer, 
		char[] nullEscape, char[][] charEscape)
	{
		super(rs, index, writer, nullEscape);
		this.ESCAPE = charEscape;
	}

	@Override
	public void write()
		throws SQLException, IOException
	{
		String s = rs.getString(index);
		if (s == null)
		{
			writer.write(NULL_ESCAPE);
		}
		else
		{
			char[] all = s.toCharArray();
			int index = 0;
			int start = 0;
			while (index < all.length)
			{
				char c = all[index];
				if (c < ESCAPE.length && ESCAPE[c] != null)
				{
					if (start < index) writer.write(all, start, index-start);
					writer.write(ESCAPE[c]);
					start = index+1;
				}
				++index;
			}
			if (start < all.length) writer.write(all, start, all.length-start);
		}
	}
	
}
