/*
	$Id: CountExpression.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.query;

import java.util.Collection;
import java.util.Collections;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.BaseException;
import net.sf.basedb.util.EqualsHelper;

/**
	Count the number of values: COUNT(e)

	@author Nicklas
	@version 2.0
	@see Aggregations#count(Expression, boolean)
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (Fri, 14 Sep 2012) $
*/
public class CountExpression
	implements Expression 
{
	private final Expression e;
	private final boolean distinct;

	CountExpression(Expression e, boolean distinct)
	{
		this.e = e;
		this.distinct = distinct;
	}

	/*
		From the QueryElement interface
		-------------------------------------------
	*/
	@Override
	public String toQl(Query query, DbControl dc)
		throws BaseException
	{
		return "COUNT(" + (distinct ? "DISTINCT " : "") + (e == null ? "*" : e.toQl(query, dc)) + ")";
	}
	/**
		@return The expression to count
	*/
	@Override
	public Collection<? extends QueryElement> getChildren()
	{
		return e == null ? null : Collections.singleton(e);
	}
	// -------------------------------------------
	/*
		From the Object class
		-------------------------------------------
	*/
	@Override
	public String toString()
	{
		return "COUNT(" + (distinct ? "DISTINCT " : "") + (e == null ? "*" : e ) + ")";
	}
	/**
		This expression is equal to another CountExpression if their 
		child expressions are equal and have the same DISTINCT setting.
	*/
	@Override
	public boolean equals(Object other)
	{
		if (this == other) return true;
		if (other == null || this.getClass() != other.getClass()) return false;
		CountExpression o = (CountExpression)other;
		return EqualsHelper.equals(e, o.e) && this.distinct == o.distinct;
	}
	@Override
	public int hashCode()
	{
		return EqualsHelper.hashCode(e) + getClass().hashCode();
	}
	// -------------------------------------------
}

