/**
	$Id: Renderer.java 8117 2023-02-22 07:58:38Z nicklas $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions;

/**
	A renderer is an object that knows how to render an action
	in the client interface. In the web client, this usually means
	outputting some HTML. In other types of clients, this may
	mean something completely different, such as creating a swing button,
	or menu item.

	@author nicklas
	@version 2.7
	@base.modified $Date: 2023-02-22 08:58:38 +0100 (Wed, 22 Feb 2023) $
*/
public interface Renderer<A extends Action>
{

	/**
		Render the action in the client application.
		@param action The action to render
		@deprecated In 3.19.8, implement the {@link #render(Action, Extension)}
			method instead. This method will never be called from the BASE 
			core except for the default implementation of {@link #render(Action, Extension)}.
	*/
	@Deprecated
	public void render(A action);
	
	/**
		Render the action in the client application.
		<p>
		The default implementation of this method simply call the {@link #render(Action)}
		method. 
		
		@param action The action to render
		@since 3.19.8
	*/
	public default void render(A action, Extension<? extends A> ext)
	{
		render(action);
	}
	
}
