/**
	$Id$

	Copyright (C) 2023 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions.logging;

import org.slf4j.Logger;

/**
	The level of the log message.
*/
public enum LogLevel
{
	INFO("info.png") 
	{
		@Override
		void logTo(Logger logger, String msg, Throwable t) 
		{
			logger.info(msg, t);
		}
	},
	WARNING("warning.png") 
	{
		@Override
		void logTo(Logger logger, String msg, Throwable t) 
		{
			logger.warn(msg, t);
		}
	},
	ERROR("error.png") 
	{
		@Override
		void logTo(Logger logger, String msg, Throwable t) 
		{
			logger.error(msg, t);
		}
	},
	DEBUG("bug.png") 
	{
		@Override
		void logTo(Logger logger, String msg, Throwable t) 
		{
			logger.debug(msg, t);
		}
	},
	TRACE("trace.png")
	{
		@Override
		void logTo(Logger logger, String msg, Throwable t) 
		{
			logger.trace(msg, t);
		}
	};
	
	private final String icon;
	
	private LogLevel(String icon)
	{
		this.icon = icon;
	}
	
	/**
		Get the icon that represents this log level.
	*/
	public String getIcon()
	{
		return icon;
	}
	
	abstract void logTo(org.slf4j.Logger logger, String msg, Throwable t);
}