/**
	$Id: AndConverter.java 6898 2015-05-12 09:27:08Z nicklas $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.jep.convert;

import net.sf.basedb.core.query.Restriction;
import net.sf.basedb.core.query.Restrictions;
import net.sf.basedb.util.jep.Jep;

import org.nfunk.jep.Node;

/**
	Convert the '&amp;&amp;' operator
	to a Query API {@link Restriction}.

	@author nicklas
	@version 2.4
	@base.modified $Date: 2015-05-12 11:27:08 +0200 (Tue, 12 May 2015) $
*/
public class AndConverter
	extends AbstractJepConversionFunction<Node>
{
	
	public AndConverter()
	{}
	
	/*
		From the JepConversionFunction interface
		-------------------------------------------
	*/
	@Override
	public boolean isOperator()
	{
		return true;
	}
	/**
		@return The string '&amp;&amp;'
	*/
	@Override
	public String getName()
	{
		return "&&";
	}
	@Override
	public String getDescription()
	{
		return "Check if both expressions are TRUE";
	}
	/**
		Convert to restriction by calling {@link Restrictions#and(Restriction[])}.
	*/
	@Override
	public Restriction toRestriction(Node node)
	{
		return Restrictions.and(
				Jep.nodeToRestriction(node.jjtGetChild(0)),
				Jep.nodeToRestriction(node.jjtGetChild(1))
			);
	}
	// -------------------------------------------

}
