/**
	$Id: ExtractNameGenerator.java 5748 2011-09-19 10:50:09Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.node;

import net.sf.basedb.core.Tag;
import net.sf.basedb.core.Extract;
import net.sf.basedb.util.overview.Node;

/**
	Name generator implementation for {@link Extract}
	items. The implementation use the {@link NameableNameGenerator}
	but prefixes the node title with the name of the tag (if present).
	Eg. <code>cy3: My labeled extract</code>.
	
	@author Nicklas
	@version 2.10
	@base.modified $Date: 2011-09-19 12:50:09 +0200 (Mon, 19 Sep 2011) $
*/
public class ExtractNameGenerator
	extends NameableNameGenerator<Extract>
{

	/**
		Create a new name generator.
		@param namePrefix The prefix to use in node names
		@param titlePrefix The prefix to use in node titles
	*/
	public ExtractNameGenerator(String namePrefix, String titlePrefix)
	{
		super(namePrefix, titlePrefix);
	}
	
	/*
		From the NameableNameGenerator class
		------------------------------------
	*/
	/**
		The base of the title is generated by the superclass. This
		implementation just prefixes the title with the name of the tag.
	*/
	@Override
	public String getNodeTitle(Extract item, Node parentNode)
	{
		String title = super.getNodeTitle(item, parentNode);
		try
		{
			Tag tag = item.getTag();
			if (tag != null && parentNode.getNodeType() == Node.Type.FOLDER) 
			{
				title = tag.getName() + ": " + title;
			}
		}
		catch (RuntimeException ex)
		{}
		return title;
	}

}
