/**
	$Id: NullIfExceptionMapper.java 7668 2019-03-21 11:50:52Z nicklas $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.parser;

import java.util.Date;

import net.sf.basedb.util.parser.FlatFileParser.Data;

/**
 	A mapper that returns null if there is an exception when parsing the
 	input data. The actual mapping is delegated to a parent mapper.

	@author nicklas
	@version 2.4
	@base.modified $Date: 2019-03-21 12:50:52 +0100 (Thu, 21 Mar 2019) $
*/
public class NullIfExceptionMapper
	implements Mapper
{

	private final Mapper parent;
	
	/**
		Create a new CropStringMapper.
		@param parent The parent mapper that does the actual mapping
	*/
	public NullIfExceptionMapper(Mapper parent)
	{
		this.parent = parent;
	}

	/*
		From the Mapper interface
		-------------------------------------------
	*/
	@Override
	@Deprecated
	public String getValue(Data data)
	{
		return getString(data);
	}
	@Override
	public String getString(Data data)
	{
		try
		{
			return parent.getString(data);
		}
		catch (Throwable t)
		{}
		return null;
	}
	@Override
	public Integer getInt(Data data)
	{
		try
		{
			return parent.getInt(data);
		}
		catch (Throwable t)
		{}
		return null;
	}
	@Override
	public Long getLong(Data data)
	{
		try
		{
			return parent.getLong(data);
		}
		catch (Throwable t)
		{}
		return null;
	}
	@Override
	public Float getFloat(Data data)
	{
		try
		{
			return parent.getFloat(data);
		}
		catch (Throwable t)
		{}
		return null;
	}
	@Override
	public Double getDouble(Data data)
	{
		try
		{
			return parent.getDouble(data);
		}
		catch (Throwable t)
		{}
		return null;
	}
	@Override
	public Date getDate(Data data)
	{
		try
		{
			return parent.getDate(data);
		}
		catch (Throwable t)
		{}
		return null;
	}
	// -------------------------------------------

}
