/* $Id$
	------------------------------------------------------------------
	Copyright (C) 2023 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var ViewLog = function()
{
	var vlog = {};
	
	vlog.initPage = function()
	{
		// Close button
		Buttons.addClickHandler('close', App.closeWindow);
		
		Buttons.addClickHandler('btnUpdate', App.reloadWindow);
		Buttons.addClickHandler('btnClearLog', vlog.clearLog);
		Events.addEventHandler('enableDebug', 'change', vlog.setOptions);
		Events.addEventHandler('copyToStdout', 'change', vlog.setOptions);
		
		// Auto-update timer
		setInterval(vlog.autoUpdate, 5000);
	}
	
	vlog.initElements = function(element, autoInit)
	{
		if (autoInit == 'toggle-stacktrace')
		{
			Buttons.addClickHandler(element, vlog.toggleStacktrace);
		}
	}

	vlog.toggleStacktrace = function(event)
	{
		var extensionId = Data.get(event.currentTarget, 'extension-id');
		Doc.showHide('stacktrace.' + extensionId);
		
		var img = event.currentTarget.firstChild;
		if (img.src.indexOf('gonext') > 0)
		{
			img.src = App.getRoot() + '/images/move_down.png';
		}
		else if (img.src.indexOf('move_down') > 0)
		{
			img.src = App.getRoot() + '/images/gonext.png';
		}
	}
	
	vlog.clearLog = function()
	{
		var extensionId = Data.get('page-data', 'extension-id');
		var url = 'index.jsp?ID='+App.getSessionId();
		url += '&cmd=ClearLog';
		url += '&extensionId='+extensionId;
		location.replace(url);
	}
	
	vlog.setOptions = function()
	{
		var extensionId = Data.get('page-data', 'extension-id');
		var url = 'index.jsp?ID='+App.getSessionId();
		url += '&cmd=SetLogOptions';
		url += '&extensionId='+extensionId;
		url += '&enableDebug='+(Doc.element('enableDebug').checked?1:0);
		url += '&copyToStdout='+(Doc.element('copyToStdout').checked?1:0);
		url += '&autoUpdate='+(Doc.element('autoUpdate').checked?1:0);;
		location.replace(url);
	}
	
	vlog.autoUpdate = function()
	{
		if (Doc.element('autoUpdate').checked)
		{
			var extensionId = Data.get('page-data', 'extension-id');
			var url = 'view_log.jsp?ID='+App.getSessionId();
			url += '&extensionId='+extensionId;
			url += '&autoUpdate=1';
			location.replace(url);
		}
	}
	
	return vlog;
}();

Doc.addElementInitializer(ViewLog.initElements);
Doc.onLoad(ViewLog.initPage);