<%-- $Id: configure.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Client"
	import="net.sf.basedb.core.User"
	import="net.sf.basedb.core.ClientDefaultSetting"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.clients.web.Base"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>

<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl(":Server configuration");

try
{
	final Client server = Client.getById(dc, sc.getClientId());
	server.checkPermission(Permission.WRITE);
	final ClientDefaultSetting adminName = server.getDefaultSetting("server.admin.name");
	final ClientDefaultSetting adminEmail = server.getDefaultSetting("server.admin.email");
	final ClientDefaultSetting about = server.getDefaultSetting("server.about");
	final ClientDefaultSetting getAccount = server.getDefaultSetting("server.get.account");
	final ClientDefaultSetting forgottenPassword = server.getDefaultSetting("server.forgotten.password");
	final ClientDefaultSetting transferRateUpload = server.getDefaultSetting("server.transferRate");
	final ClientDefaultSetting transferRateDownload = server.getDefaultSetting("server.transferRate.download");
	final ClientDefaultSetting reportbuglink = server.getDefaultSetting("server.links.reportbug");
	final ClientDefaultSetting helplink = server.getDefaultSetting("server.links.help");
	final ClientDefaultSetting faqlink = server.getDefaultSetting("server.links.faq");
	%>
	<base:page type="popup" title="Server configuration">
	<base:head scripts="tabcontrol-2.js,~configure.js" styles="tabcontrol.css" />
	<base:body >
		<h1>Server configuration <base:help tabcontrol="settings" /></h1>
		<form name="server" action="submit_server.jsp" method="post">
		<input type="hidden" name="ID" value="<%=ID%>">
		<input type="hidden" name="cmd" value="SaveSettings">
	
		<t:tabcontrol id="settings" 
			subclass="content dialogtabcontrol"
			position="bottom">
		<t:tab id="filetransfer" title="File transfer" helpid="serverconfig.filetransfer">
			<div>
			<table class="fullform bottomborder">
			<tr>
				<th>Max upload rate</th>
				<td>
					<%
					long bytes = Values.getLong(transferRateUpload.getValue());
					String fBytes = "";
					if (bytes > 0)
					{
						fBytes = Values.formatBytes(bytes);
					}
					else
					{
						fBytes = "unlimited";
					}
					%>
					<input class="text"	<%=bytes==0 ? " disabled" : ""%>
						type="text" name="transfer_rate_upload" value="<%=fBytes%>" size="16" maxlength="16"> per second<br>
					
				</td>
			</tr>
			<tr>
				<th class="subprompt"></th>
				<td>
					<input type="checkbox" value="1" name="unlimited_upload" <%=bytes==0 ? " checked" : ""%>
						id="unlimited.upload" data-rate-field="transfer_rate_upload"
						title="Unlimited transfer rate">
						<label for="unlimited.upload">Unlimited</label>
				</td>
			</tr>
			<tr>
				<th>Max download rate</th>
				<td>
					<%
					bytes = Values.getLong(transferRateDownload.getValue());
					fBytes = "";
					if (bytes > 0)
					{
						fBytes = Values.formatBytes(bytes);
					}
					else
					{
						fBytes = "unlimited";
					}
					%>
					<input class="text"	<%=bytes==0 ? " disabled" : ""%>
						type="text" name="transfer_rate_download" value="<%=fBytes%>" size="16" maxlength="16"> per second<br>
					
				</td>
			</tr>
			<tr>
				<th class="subprompt"></th>
				<td>
					<input type="checkbox" value="1" name="unlimited_download" <%=bytes==0 ? " checked" : ""%>
						id="unlimited.download" data-rate-field="transfer_rate_download"
						title="Unlimited transfer rate">
						<label for="unlimited.download">Unlimited</label>
				</td>
			</tr>

			</table>
			</div>


			<div class="padded">
					The transfer rate is specified in bytes per second.
					You can use the following units (case-insensitive):
					<ul>
					<li><b>GB</b> or <b>G</b> for gigabyte values (<code>1.5 GB</code>)
					<li><b>MB</b> or <b>M</b> for megabyte values (<code>10M</code>)
					<li><b>kB</b> or <b>k</b> for kilobyte values (<code>800k</code>)
					<li><b>bytes</b> or <b>B</b> for byte values (<code>50 bytes</code>)
					</ul>
			</div>


		</t:tab>
		<t:tab id="about" title="About" helpid="serverconfig.about">
			<table class="fullform input100">
			<tr>
				<th>Administrator name</th>
				<td>
					<input class="text" type="text" name="name" value="<%=HTML.encodeTags(adminName.getValue())%>" maxlength="<%=User.MAX_NAME_LENGTH%>">
				</td>
				<td></td>
			</tr>
			<tr>
				<th>Administrator email</th>
				<td>
					<input class="text" type="text" name="email" value="<%=HTML.encodeTags(adminEmail.getValue())%>" maxlength="<%=User.MAX_EMAIL_LENGTH%>">
				</td>
				<td></td>
			</tr>
			<tr class="dynamic">
				<th>About</th>
				<td>
					<textarea class="text" rows="10" name="about" id="aboutMsg"><%=HTML.encodeTags(about.getValue())%></textarea>
				</td>
				<td style="width: 20px;">
					<base:zoom textarea="aboutMsg" title="About" />
				</td>
			</tr>
			</table>
		</t:tab>
		<t:tab id="account" title="Get account" helpid="serverconfig.getaccount">
			<table class="fullform input100 smaller">
			<tr class="dynamic">
				<th>Message</th>
				<td>
					<textarea class="text" rows="16" name="account" id="accountMsg"><%=HTML.encodeTags(getAccount.getValue())%></textarea>
				</td>
				<td style="width: 20px;">
					<base:zoom textarea="accountMsg" title="Get account - message" />
				</td>
			</tr>
			</table>
		</t:tab>
		
		<t:tab id="password" title="Forgotten password" helpid="serverconfig.password">
			<table class="fullform input100 smaller">
			<tr class="dynamic">
				<th>Message</th>
				<td>
					<textarea class="text" rows="16" name="password" id="passwordMsg"><%=HTML.encodeTags(forgottenPassword.getValue())%></textarea>
				</td>
				<td style="width: 20px;">
					<base:zoom textarea="passwordMsg" title="Forgotten password - message" />
				</td>
			</tr>
			</table>
		</t:tab>

		<t:tab id="links" title="Links" helpid="serverconfig.links">
		    <table class="fullform input100 smaller">
		     <tr>
				<th>Help</th>
				<td>
					<input class="text" type="text" name="help" 
						value="<%=HTML.encodeTags(helplink.getValue())%>" 
						maxlength="<%=ClientDefaultSetting.MAX_VALUE_LENGTH%>">
				</td>
			</tr>
			<tr>
				<th>FAQ</th>
				<td>
					<input class="text" type="text" name="faq" 
						value="<%=HTML.encodeTags(faqlink.getValue())%>" 
						maxlength="<%=ClientDefaultSetting.MAX_VALUE_LENGTH%>">
				</td>
			</tr>
			<tr>
				<th>Report a bug</th>
				<td>
					<input class="text" type="text" name="reportbug" 
						value="<%=HTML.encodeTags(reportbuglink.getValue())%>"
						maxlength="<%=ClientDefaultSetting.MAX_VALUE_LENGTH%>">
				</td>
			</tr>
			<tr class="dynamic">
				<th></th>
				<td></td>
			</tr>
			</table>		
		</t:tab>
		</t:tabcontrol>

		</form>
		
		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Ok" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>

