/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var SelectFile = function()
{
	var select = {};
	
	/**
		Initialize the page.
	*/
	select.initPage = function()
	{
		// Buttons
		Buttons.addClickHandler('close', App.closeWindow);
		Buttons.addClickHandler('btnNext', select.next);
		Buttons.addClickHandler('btnBrowse', select.browseOnClick);
		Events.addEventHandler('path', 'base-selected', select.setFileCallback);
		
		Events.addEventHandler('recentFile', 'change', select.recentFileOnChange);
		Events.addEventHandler('dataFile', 'change', select.dataFileOnChange);
	}
	
	select.browseOnClick = function()
	{
		var url = '&title=Select+file+to+import+from';
		Dialogs.selectItem('FILE', 'path', 0, url);
	}
	
	select.setFileCallback = function(event)
	{
		var fileId = event.detail.id;
		var path = event.detail.name;
		select.setFile(fileId, path);
	}
	
	select.setFile = function(fileId, path)
	{
		var frm = document.forms['import'];
		frm.file_id.value = fileId;
		frm.path.value = path;
		select.updateCharset(fileId);
	}
	
	select.updateCharset = function(fileId)
	{
		var request = Ajax.getXmlHttpRequest();
		if (request != null)
		{
			var url = App.getRoot()+'filemanager/files/ajax.jsp?ID='+App.getSessionId();
			url += '&cmd=GetFileInfo&item_id=' + fileId;
			request.open("GET", url, true);
			Ajax.setReadyStateHandler(request, select.updateCharsetCallback);
			request.send(null);
		}
		return request != null;
	}
	
	select.updateCharsetCallback = function(request)
	{
		var response = JSON.parse(request.responseText);
		if (response.status != 'ok') return;
		var charset = response.characterSet;
		if (!charset) charset = Data.get('page-data', 'default-charset');
		var frm = document.forms['import'];
		Forms.selectListOption(frm.charset, charset);
	}

	select.recentFileOnChange = function()
	{
		var frm = document.forms['import'];
		var selected = frm.recentFile[frm.recentFile.selectedIndex];
		select.setFile(selected.value, selected.text);
		frm.recentFile.selectedIndex = 0;
	}
	
	select.dataFileOnChange = function()
	{
		var frm = document.forms['import'];
		var selected = frm.dataFile[frm.dataFile.selectedIndex];
		select.setFile(selected.value, selected.text.replace(/\[.*\]\s/, ''));
		frm.dataFile.selectedIndex = 0;
	}
	
	select.next = function()
	{
		var frm = document.forms['import'];
		if (Strings.trim(frm.path.value) == '')
		{
			Forms.showNotification('btnBrowse', 'You must select a file to import from');
		}
		else
		{
			frm.submit();
		}
	}

	
	return select;
}();

Doc.onLoad(SelectFile.initPage);