<%-- $Id: edit_directory.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------


	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.Directory"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.BaseException"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.edit.EditUtil"
	import="net.sf.basedb.clients.web.extensions.tabcontrol.TabAction"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.List"
	import="java.util.Set"
	import="java.util.HashSet"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%
final Item itemType = Item.DIRECTORY;
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl(":Edit "+itemType);
try
{
	String title = null;
	Directory directory = null;
	Directory parent = null;
	boolean autoCompress = false;
	boolean autoShare = false;

	if (itemId == 0)
	{
		title = "Create directory";
		parent = Directory.getById(dc, Values.getInt(request.getParameter("parent_id"), 
			SystemItems.getId(Directory.ROOT))
		);
		autoCompress = parent.getAutoCompress();
		autoShare = parent.getAutoShare();
		cc.removeObject("item");
	}
	else
	{
		directory = Directory.getById(dc, itemId);
		directory.checkPermission(Permission.WRITE);
		parent = directory.getParent();
		autoCompress = directory.getAutoCompress();
		autoShare = directory.getAutoShare();
		cc.setObject("item", directory);
		title = "Edit directory -- " + HTML.encodeTags(directory.getName());
	}
	
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.item(itemType), directory);
	ExtensionsInvoker<TabAction> invoker = EditUtil.useEditExtensions(jspContext);
	%>
	<base:page type="popup" title="<%=title%>" id="edit-page">
	<base:head scripts="tabcontrol-2.js,~directories.js" styles="tabcontrol.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		<h1><%=title%> <base:help tabcontrol="settings" /></h1>

		<form action="index.jsp?ID=<%=ID%>" method="post" name="directory">
		<input type="hidden" name="cmd" value="UpdateItem">
		<input type="hidden" name="parent_id" value="<%=parent.getId()%>">
		
		<t:tabcontrol id="settings" 
			subclass="content dialogtabcontrol"
			position="bottom" remember="<%=directory != null%>"
			extensions="<%=invoker%>">
		<t:tab id="info" title="Directory" helpid="directory.edit">
			<table class="fullform input100">
			<tr>
				<th>Path</th>
				<td colspan="2"><%=HTML.encodeTags(parent.getPath().toString())%></td>
			</tr>
			<tr>
				<th>Name</th>
				<td><input class="text required auto-init"
					data-auto-init="<%=directory == null ? "focus-select" : "focus" %>"
					type="text" name="name" 
					value="<%=HTML.encodeTags(directory == null ? Values.getString(cc.getPropertyValue("name"), "New directory") : directory.getName())%>" 
					maxlength="<%=Directory.MAX_NAME_LENGTH%>"></td>
				<td></td>
			</tr>
			<tr>
				<th>Compress new files</th>
				<td>
					<input type="radio" name="autoCompress" id="autoCompressNo" value="0" 
						<%=!autoCompress ? "checked" : ""%>><label for="autoCompressNo">no</label>
					<input type="radio" name="autoCompress" id="autoCompressYes" value="1" 
						<%=autoCompress ? "checked" : ""%>><label for="autoCompressYes">yes</label>
					<span title="Select this checkbox to set this property on all subdirectories">
					<input type="checkbox" name="autoCompressRecursive" id="autoCompressRecursive" value="1"
						><label for="autoCompressRecursive">Recursive</label></span>
				</td>
				<td></td>
			</tr>	
			<tr>
				<th>
					Share new files and sub-<br>
					directories automatically
				</th>
				<td>
					<input type="radio" name="autoShare" id="autoShareNo" value="0" 
						<%=!autoShare ? "checked" : ""%>><label for="autoShareNo">no</label>
					<input type="radio" name="autoShare" id="autoShareYes" value="1" 
						<%=autoShare ? "checked" : ""%>><label for="autoShareYes">yes</label>
					<span title="Select this checkbox to set this property on all subdirectories">
					<input type="checkbox" name="autoShareRecursive" id="autoShareRecursive" value="1"
						><label for="autoShareRecursive">Recursive</label></span>
				</td>
				<td></td>
			</tr>	
			<tr class="dynamic">
				<th>Description</th>
				<td>
					<textarea class="text" rows="4" name="description" id="description"
						><%=HTML.encodeTags(directory == null ? cc.getPropertyValue("description") : directory.getDescription())%></textarea>
				</td>
				<td style="width: 20px;">
					<base:zoom textarea="description" title="Description" />
				</td>
			</tr>
			</table>
		</t:tab>
		</t:tabcontrol>
		</form>

		<div class="legend">
			<base:icon image="required.png" />= required information
		</div>

		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Save" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
