<%-- $Id: merge_plates_2.jsp 7954 2021-05-12 13:27:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------


	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.Plate"
	import="net.sf.basedb.core.PlateMapping"
	import="net.sf.basedb.core.PlateType"
	import="net.sf.basedb.core.PlateGeometry"
	import="net.sf.basedb.core.BaseException"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.WebException"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%
final Item itemType = Item.PLATE;
final SessionControl sc = Base.getExistingSessionControl(pageContext, Permission.CREATE, itemType);
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl(":Merge plates wizard step 2");
try
{
	final int plateMappingId = Values.getInt(request.getParameter("platemapping_id"));
	final int plateTypeId = Values.getInt(request.getParameter("platetype_id"));
	final PlateMapping plateMapping = PlateMapping.getById(dc, plateMappingId);
	final PlateType plateType = PlateType.getById(dc, plateTypeId);
	PlateGeometry sourceGeometry = plateMapping.getSourceGeometry();
	
	if (!plateMapping.getDestinationGeometry().equals(plateType.getPlateGeometry()))
	{
		throw new WebException("popup", "Incomatible plate type and plate mapping", 
			"The selected plate type has a different geometry than the mapping.");
	}
	
	String title = "Merge plates -- step 2 of 2 -- Select plates";
	%>
	<base:page type="popup" title="<%=title%>" id="step-2">
	<base:head scripts="linkitems-2.js,~merge_plates.js" />
	<base:body>
		<h1><%=title%> <base:help helpid="plates.merge.2" /></h1>

		<div id="page-data" class="datacontainer"
			data-source-count="<%=plateMapping.getSourceCount()%>"
		></div>

		<form action="index.jsp?ID=<%=ID%>" method="post" name="merge">
		<input type="hidden" name="cmd" value="MergePlates">
		<input type="hidden" name="platemapping_id" value="<%=plateMappingId%>">
		<input type="hidden" name="platetype_id" value="<%=plateTypeId%>">

		<div class="content bottomborder">
			<table class="fullform input100 smaller">
			<tr>
				<th>Plate mapping</th>
				<td>
					<table><tr>
						<td><%=HTML.encodeTags(plateMapping.getName())%></td>
					<%
					if (plateMapping.getImage() !=  null)
					{
						%>
						<td><img src="../../images/platemappings/<%=plateMapping.getImage()%>" alt=""></td>
						<%
					}
					%>
					</tr></table>
				</td>
			</tr>
			<tr>
				<th>Name</th>
				<td><input class="text required" type="text" name="name" value="<%=HTML.encodeTags(request.getParameter("name"))%>" 
					maxlength="<%=Plate.MAX_NAME_LENGTH%>"></td>
			</tr>
			<tr>
				<th>Plate type</th>
				<td><%=HTML.encodeTags(plateType.getName())%></td>
			</tr>
			<tr class="big">
				<th>Plates</th>
				<td>
				<table>
				<tr>
					<td style="padding: 5px;">
						<base:buttongroup vertical="true">
							<base:button
								id="moveUp"
								data-down="0"
								image="move_up.png" 
								tooltip="Move up" 
								subclass="square"
							/>
							<base:button 
								id="moveDown"
								data-down="1"
								image="move_down.png" 
								tooltip="Move down" 
								subclass="square"
							/>
						</base:buttongroup>
					</td>
					<td>
						<select name="plates" id="plates" 
							class="auto-init"
							data-auto-init="link-container"
							size="<%=Math.max(5, plateMapping.getSourceCount())%>" 
							multiple style="width: 15em;" class="required">
						</select>
					</td>
					<td>
						<base:buttongroup vertical="true">
							<base:button 
								subclass="leftaligned auto-init"
								data-auto-init="add-link"
								data-list-id="plates"
								data-item-type="PLATE"
								data-extra-url="<%="&resetTemporary=1&tmpfilter:INT:plateType.plateGeometry="+sourceGeometry.getId()%>" 
								style="width: 14em;"
								title="Add&nbsp;plates&hellip;" 
								tooltip="Add plates to be used"
							/>
							<base:button 
								subclass="leftaligned auto-init"
								data-auto-init="remove-link"
								data-list-id="plates"
								style="width: 14em;"
								title="Remove" 
								tooltip="Remove the selected plates"
							/>
						</base:buttongroup>
					</td>
					</tr>
					</table>
				</td>
			</tr>
			<tr class="dynamic">
				<th></th>
				<td></td>
			</tr>
			</table>
		</div>
		</form>
		
		<div class="legend">
			<base:icon image="required.png" />= required information
		</div>
		
		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnMerge" title="Merge" image="gonext.png"/>
			<base:button id="close" title="Cancel" />
		</base:buttongroup>

	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
