<%-- $Id$
	------------------------------------------------------------------
	Copyright (C) 2015 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.ItemList"
	import="net.sf.basedb.core.RawDataType"
	import="net.sf.basedb.core.ItemSubtype"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="java.util.List"
	import="java.util.ArrayList"
	import="java.util.Set"
	import="java.util.HashSet"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%
final Item itemType = Item.ITEMLIST;
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl(":Re-sync item lists");
try
{
	ItemList itemList = ItemList.getById(dc, itemId);
	String title = "Re-sync: " + HTML.encodeTags(itemList.getName());
	itemList.checkPermission(Permission.WRITE);
	ItemSubtype subtype = itemList.getItemSubtype();
	RawDataType rawDataType = itemList.getRawDataType();
	
	// Load depending lists
	List<ItemList> depending = new ArrayList<ItemList>();
	
	List<ItemList> toCheck = new ArrayList<ItemList>(itemList.getDependingLists().list(dc));
	Set<ItemList> checked = new HashSet<ItemList>();
	while (toCheck.size() > 0)
	{
		ItemList i = toCheck.remove(0);
		if (checked.contains(i)) continue; // Skip lists that have already been checked
		
		checked.add(i);
		
		if (!i.getDisableSyncFilters() && i.hasSyncFilters())
		{
			// We depend on this list and should also check recursively
			depending.add(i);
			toCheck.addAll(i.getDependingLists().list(dc));
		}
	}
	%>
	<base:page type="popup" title="<%=title%>">
	<base:head scripts="~resync.js" />
	<base:body>
		<h1><%=title%> <base:help helpid="itemlist.resync" /></h1>
		<form action="index.jsp?ID=<%=ID%>" method="post" name="resync">
		<input type="hidden" name="cmd" value="ReSync">
		<input type="hidden" name="item_id" value="<%=itemId%>">

		<div class="content bottomborder">
			<table class="fullform input100">
			<tr class="big">
				<th>Sync options</th>
				<td>
					<label><input type="radio" name="syncoption" 
						value="FULL" checked>Full</label> - add and remove members<br>
					<label><input type="radio" name="syncoption" 
						value="ADD_ONLY">Add only</label> - add members matching the filters<br>
					<label><input type="radio" name="syncoption" 
						value="REMOVE_ONLY">Remove only</label> - remove members not matching the filters<br>
				</td>
			</tr>
			<%
			if (subtype != null)
			{
				%>
				<tr>
					<th>Subtype</th>
					<td>
						<label><input type="checkbox" name="subtype" checked value="<%=subtype.getId()%>"
							>Filter on <i><%=HTML.encodeTags(subtype.getName())%></i></label>
					</td>
				</tr>
				<%
			}
			if (rawDataType != null)
			{
				%>
				<tr>
					<th>Raw data type</th>
					<td style="padding-bottom: 0.5em; padding-top: 0.5em;">
						<label><input type="checkbox" name="rawdatatype" checked value="<%=rawDataType.getId()%>"
							>Filter on <i><%=HTML.encodeTags(rawDataType.getName())%></i></label>
					</td>
				</tr>
				<%
			}
			%>
			<tr class="dynamic">
				<th>Depending lists</th>
				<td>
					<%
					if (depending.size() > 0)
					{
						for (ItemList d : depending)
						{
							boolean canSync = d.hasPermission(Permission.WRITE);
							boolean inSync = d.isInSync(dc);
							%>
							<label><input type="checkbox" name="depending" value="<%=d.getId() %>"
								<%=canSync ? "" : "disabled" %> <%=!inSync && canSync ? "checked" : "" %>
								><%=HTML.encodeTags(d.getName()) %></label> 
								<i>(<%=canSync ? (inSync ? "appears to be in sync" : "not in sync") : "no write permissions" %>)</i><br>
							<%
						}
						%>
						<div class="messagecontainer note">
							The item lists above are used by the filters in this list.<br>
							Selected lists will be synchronized before this list is synchronized.
						</div>
						<%
					}
					else
					{
						%>
						<div class="messagecontainer note">
							This list doesn't depend on any other item lists.
						</div>
						<%
					}
					%>
				</td>
			</tr>
			</table>
		
		</div>
		</form>
		
		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Ok" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
